@@ -29,7 +29,7 @@ pub struct IdentityAnyIdAccessControl;
 
 #[async_trait]
 impl AccessControl for IdentityAnyIdAccessControl {
-    async fn is_authorized(&mut self, local_msg: &LocalMessage) -> Result<bool> {
+    async fn is_authorized(&self, local_msg: &LocalMessage) -> Result<bool> {
         Ok(IdentitySecureChannelLocalInfo::find_info(local_msg).is_ok())
     }
 }
@@ -40,7 +40,7 @@ pub struct IdentityIdAccessControl {
 
 #[async_trait]
 impl AccessControl for IdentityIdAccessControl {
-    async fn is_authorized(&mut self, local_msg: &LocalMessage) -> Result<bool> {
+    async fn is_authorized(&self, local_msg: &LocalMessage) -> Result<bool> {
         if let Ok(msg_identity_id) = IdentitySecureChannelLocalInfo::find_info(local_msg) {
             Ok(msg_identity_id.their_identity_id() == &self.their_identity_id)
         } else {
@@ -57,7 +57,7 @@ mod test {
     use ockam_core::compat::sync::Arc;
     use ockam_core::{route, Any, Route, Routed, Worker};
     use ockam_node::Context;
-    use ockam_vault_sync_core::Vault;
+    use ockam_vault::Vault;
     use std::time::Duration;
     use tokio::time::sleep;
 
@@ -66,8 +66,8 @@ mod test {
         let alice_vault = Vault::create();
         let bob_vault = Vault::create();
 
-        let mut alice = Identity::create(ctx, &alice_vault).await?;
-        let mut bob = Identity::create(ctx, &bob_vault).await?;
+        let alice = Identity::create(ctx, &alice_vault).await?;
+        let bob = Identity::create(ctx, &bob_vault).await?;
 
         let alice_trust_policy = TrustIdentifierPolicy::new(bob.identifier().await?);
         let bob_trust_policy = TrustIdentifierPolicy::new(alice.identifier().await?);
@@ -108,8 +108,8 @@ mod test {
     async fn test_tunneled_secure_channel_works(ctx: &mut Context) -> Result<()> {
         let vault = Vault::create();
 
-        let mut alice = Identity::create(ctx, &vault).await?;
-        let mut bob = Identity::create(ctx, &vault).await?;
+        let alice = Identity::create(ctx, &vault).await?;
+        let bob = Identity::create(ctx, &vault).await?;
 
         let alice_trust_policy = TrustIdentifierPolicy::new(bob.identifier().await?);
         let bob_trust_policy = TrustIdentifierPolicy::new(alice.identifier().await?);
@@ -153,8 +153,8 @@ mod test {
     async fn test_double_tunneled_secure_channel_works(ctx: &mut Context) -> Result<()> {
         let vault = Vault::create();
 
-        let mut alice = Identity::create(ctx, &vault).await?;
-        let mut bob = Identity::create(ctx, &vault).await?;
+        let alice = Identity::create(ctx, &vault).await?;
+        let bob = Identity::create(ctx, &vault).await?;
 
         let alice_trust_policy = TrustIdentifierPolicy::new(bob.identifier().await?);
         let bob_trust_policy = TrustIdentifierPolicy::new(alice.identifier().await?);
@@ -208,8 +208,8 @@ mod test {
     async fn test_many_times_tunneled_secure_channel_works(ctx: &mut Context) -> Result<()> {
         let vault = Vault::create();
 
-        let mut alice = Identity::create(ctx, &vault).await?;
-        let mut bob = Identity::create(ctx, &vault).await?;
+        let alice = Identity::create(ctx, &vault).await?;
+        let bob = Identity::create(ctx, &vault).await?;
 
         let alice_trust_policy = TrustIdentifierPolicy::new(bob.identifier().await?);
         let bob_trust_policy = TrustIdentifierPolicy::new(alice.identifier().await?);
@@ -281,8 +281,8 @@ mod test {
 
         let vault = Vault::create();
 
-        let mut alice = Identity::create(ctx, &vault).await?;
-        let mut bob = Identity::create(ctx, &vault).await?;
+        let alice = Identity::create(ctx, &vault).await?;
+        let bob = Identity::create(ctx, &vault).await?;
 
         let access_control = IdentityAccessControlBuilder::new_with_id(alice.identifier().await?);
         ctx.start_worker_with_access_control("receiver", receiver, access_control)
@@ -317,8 +317,8 @@ mod test {
 
         let vault = Vault::create();
 
-        let mut alice = Identity::create(ctx, &vault).await?;
-        let mut bob = Identity::create(ctx, &vault).await?;
+        let alice = Identity::create(ctx, &vault).await?;
+        let bob = Identity::create(ctx, &vault).await?;
 
         let access_control = IdentityAccessControlBuilder::new_with_id(bob.identifier().await?);
         ctx.start_worker_with_access_control("receiver", receiver, access_control)
