@@ -135,12 +135,15 @@ impl IdentitySerializationUtil {
 #[cfg(test)]
 mod test {
     use super::*;
-    use ockam_core::Error;
+    use ockam_core::{
+        errcode::{Kind, Origin},
+        Error,
+    };
     use ockam_node::Context;
     use ockam_vault::Vault;
 
     fn test_error<S: Into<String>>(msg: S) -> Result<()> {
-        Err(Error::new(0, msg.into()))
+        Err(Error::new_without_cause(Origin::Identity, Kind::Unknown).context("msg", msg.into()))
     }
 
     async fn test_basic_identity_key_ops(identity: &mut (impl IdentityTrait + Sync)) -> Result<()> {
@@ -234,7 +237,7 @@ mod test {
 
         for r in results {
             match r {
-                Err(e) => panic!("{}", e.domain().clone()),
+                Err(e) => panic!("{}", e.code().clone()),
                 _ => (),
             }
         }
